﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework;

namespace CreaStelline
{
    class Character : DrawableGameComponent
    {

        private SpriteBatch spriteBatch;

        // Indice dell'animazione corrente
        private int currentAnimationIndex = 0;
        // Array contenente tutte le animazioni del Character
        public Animation[] Animations { get; set; }
        // Posizione corrente del Character
        public Vector2 Position { get; set; }

        // Costruttori
        public Character(Game game, Vector2 InitialPosition) : base(game) { this.Position = InitialPosition; }
        public Character(Game game) : this(game, new Vector2(0, 0)) { }

        protected override void LoadContent()
        {
            base.LoadContent();

            // Otteniamo lo spriteBatch del gioco
            spriteBatch = (SpriteBatch)Game.Services.GetService(typeof(SpriteBatch));
        }

        public override void Update(GameTime gameTime)
        {
            base.Update(gameTime);

            // Aggiorna le variabili dell'animazione
            while (!this.CurrentAnimation.Update(gameTime))
            {
                // L'animazione è finita, passiamo alla successiva
                Animation oldAnimation = CurrentAnimation;
                CurrentAnimation = Animations[(currentAnimationIndex + 1) % Animations.Length];
                CurrentAnimation.Start(gameTime);
                CurrentAnimation.InitalAngle = oldAnimation.CurrentRotation;
            }
        }

        public override void Draw(GameTime gameTime)
        {
            base.Draw(gameTime);

            // Disegnamo il character con tutte le informazioni
            // che ci vengono da this.CurrentAnimation, eccetto
            // la posizione corrente
            spriteBatch.Draw(this.CurrentAnimation.Frames,
                this.Position, this.CurrentAnimation.CurrentRectangle,
                Color.White, (float)this.CurrentAnimation.CurrentRotation, 
                this.CurrentAnimation.RotationPoint,
                this.CurrentAnimation.Scale, SpriteEffects.None, 0);
        }

        public Animation CurrentAnimation
        {
            get { return Animations[currentAnimationIndex]; }
            set
            {
                currentAnimationIndex = Array.IndexOf(Animations, value);
                if (currentAnimationIndex == -1) throw new IndexOutOfRangeException();
            }

        }

    }

}
